!
!-----------------------------------------------------------------------
!     Subroutine KT17_DIPOLE
!-----------------------------------------------------------------------
!
subroutine kt17_dipole(xmsm,ymsm,zmsm,bx,by,bz)

! calculates components of dipole field
!
! input parameters: x,y,z - msm coordinates in rm (1 rm = 2440 km)
!
! output parameters: bx,by,bz - field components in msm system, in nanotesla.

  implicit none
  
  include 'kt17_common.f90'
  
  real*8        xmsm,ymsm,zmsm
  real*8        bx,by,bz
  real*8        psi,sps,cps
  real*8        p,u,v,t,q

! dipole tilt
  psi=0.0d0
  sps=sin(psi/57.29577951d0)
  cps=sqrt(1.0d0-sps**2)

! compute field components
  p=xmsm**2
  u=zmsm**2
  v=3.0d0*zmsm*xmsm
  t=ymsm**2
  q=mu/sqrt(p+t+u)**5
  bx=q*((t+u-2.0d0*p)*sps-v*cps)
  by=-3.0d0*ymsm*q*(xmsm*sps+zmsm*cps)
  bz=q*((p+t-2.0d0*u)*cps-v*sps)

return
end
