!
!-----------------------------------------------------------------------
!     Subroutine KT17_MPDIST
!-----------------------------------------------------------------------
!
subroutine kt17_mpdist(mode,x,y,z,fi,id,gradfix,gradfiy,gradfiz)

  implicit none
  
  include 'kt17_common.f90'
  
  integer*4   mode,id
  real*8      x,y,z,fi,gradfix,gradfiy,gradfiz
  real*8      rho2,r,rho
  real*8      ct,st,t,sp,cp
  real*8      rm,drm_dt
  real*8      gradfir,gradfit,gradfip

  rho2=y**2+z**2
  r=sqrt(x**2+rho2)
  rho=sqrt(rho2)
  
  id=1

  if (rho .gt. 1.0d-8) then        ! not on the x-axis - no singularities to worry about
    ct=x/r
    st=rho/r
    t=atan2(st,ct)
    sp=z/rho
    cp=y/rho
  else                             ! on the x-axis
    if (x .gt. 0.0d0) then         ! on the dayside
      ct=x/r
      st=1.0d-8/r                  ! set rho=10**-8, to avoid singularity of grad_fi (if mode=1, see gradfip=... below)
      t=atan2(st,ct)
      sp=0.0d0
      cp=1.0d0
    else                           ! on the tail axis! to avoid singularity:
      fi=-1000.0d0                 ! assign rm=1000 (a conventional substitute value)
      return                       ! and exit
    endif
  endif

  rm=r0/sqrt(alfa*(1.0d0+ct))      ! standard form of shue et al.,1997, magnetopause model

  if (rm .lt. r) id=-1

  fi=r-rm
  if (mode .eq. 0) return          ! skip calculation of the gradient of fi

  drm_dt=0.25d0*rm**3/r0**2*st

  gradfir=1.0d0
  gradfit=-drm_dt/r
  gradfip=0.0d0                    !  axial symmetry

  gradfix=gradfir*ct-gradfit*st
  gradfiy=(gradfir*st+gradfit*ct)*cp-gradfip*sp
  gradfiz=(gradfir*st+gradfit*ct)*sp+gradfip*cp

  return
end
