!
!-----------------------------------------------------------------------
!     Subroutine KT17_TAILSLAB
!-----------------------------------------------------------------------
!
subroutine kt17_tailslab(xmsm,ymsm,zmsm,bx,by,bz)

! calculates msm components of the field from an equatorial harris-type current sheet,
! slowly expanding sunward
!
!------------input parameters:
!
! d0       - basic (minimal) half-thickness
! deltadx  - sunward expansion factor for the current sheet thickness
! deltady  - flankward expansion factor for the current sheet thickness
! scalex   - e-folding distance for the sunward expansion of the current sheet
! scaley   - scale distance for the flankward expansion of the current sheet
! zshift   - z shift of image sheets
! x,y,z    - msm coordinates
!
!------------output parameters:
! bx,by,bz - field components in msm system, in nanotesla.

  implicit none
  
  include 'kt17_common.f90'
  
  real*8   xmsm,ymsm,zmsm,bx,by,bz
  real*8   d,dddx,zpzi,zmzi

  d=d0+deltadx*exp(xmsm/scalex)+deltady*(ymsm/scaley)**2
  dddx=deltadx/scalex*exp(xmsm/scalex)
  zpzi=zmsm+zshift
  zmzi=zmsm-zshift
  bx=(tanh(zmsm/d)-0.5d0*(tanh(zmzi/d)+tanh(zpzi/d)))/d
  by=0.0d0
  bz=(zmsm*tanh(zmsm/d)-0.5d0*(zmzi*tanh(zmzi/d)+zpzi*tanh(zpzi/d)))*dddx/d**2
  
return
end
